# Interface: WebpackEnvOptions

Represents all relevant options that are passed to Webpack config function,
needed to create a valid Webpack configuration and configure all plugins.

This is the return type of {@link parseCliOptions}.

## Table of contents

### Properties

- [assetsPath](WebpackEnvOptions.md#assetspath)
- [bundleFilename](WebpackEnvOptions.md#bundlefilename)
- [context](WebpackEnvOptions.md#context)
- [devServer](WebpackEnvOptions.md#devserver)
- [entry](WebpackEnvOptions.md#entry)
- [minimize](WebpackEnvOptions.md#minimize)
- [mode](WebpackEnvOptions.md#mode)
- [platform](WebpackEnvOptions.md#platform)
- [reactNativePath](WebpackEnvOptions.md#reactnativepath)
- [sourceMapFilename](WebpackEnvOptions.md#sourcemapfilename)

## Properties

### assetsPath

• `Optional` **assetsPath**: `string`

Assets output path - directory where generated static assets will be saved.

#### Defined in

[packages/repack/src/types.ts:159](https://github.com/callstack/repack/blob/9e6a11a/packages/repack/src/types.ts#L159)

___

### bundleFilename

• `Optional` **bundleFilename**: `string`

Bundle output filename - name under which generated bundle will be saved.

#### Defined in

[packages/repack/src/types.ts:151](https://github.com/callstack/repack/blob/9e6a11a/packages/repack/src/types.ts#L151)

___

### context

• `Optional` **context**: `string`

Context in which all resolution happens. Usually it's project root directory.

#### Defined in

[packages/repack/src/types.ts:145](https://github.com/callstack/repack/blob/9e6a11a/packages/repack/src/types.ts#L145)

___

### devServer

• `Optional` **devServer**: [`DevServerOptions`](DevServerOptions.md)

Development server configuration options.
Used to configure `@callstack/repack-dev-server`.

If `undefined`, then development server should not be run.

#### Defined in

[packages/repack/src/types.ts:173](https://github.com/callstack/repack/blob/9e6a11a/packages/repack/src/types.ts#L173)

___

### entry

• `Optional` **entry**: `string`

Input filename - entry point of the bundle.

#### Defined in

[packages/repack/src/types.ts:148](https://github.com/callstack/repack/blob/9e6a11a/packages/repack/src/types.ts#L148)

___

### minimize

• `Optional` **minimize**: `boolean`

Whether to minimize the final bundle.

#### Defined in

[packages/repack/src/types.ts:162](https://github.com/callstack/repack/blob/9e6a11a/packages/repack/src/types.ts#L162)

___

### mode

• `Optional` **mode**: ``"development"`` \| ``"production"``

Compilation mode.

#### Defined in

[packages/repack/src/types.ts:139](https://github.com/callstack/repack/blob/9e6a11a/packages/repack/src/types.ts#L139)

___

### platform

• `Optional` **platform**: `string`

Target application platform.

#### Defined in

[packages/repack/src/types.ts:142](https://github.com/callstack/repack/blob/9e6a11a/packages/repack/src/types.ts#L142)

___

### reactNativePath

• `Optional` **reactNativePath**: `string`

Path to React Native dependency. Usually points to `node_modules/react-native`.

#### Defined in

[packages/repack/src/types.ts:165](https://github.com/callstack/repack/blob/9e6a11a/packages/repack/src/types.ts#L165)

___

### sourceMapFilename

• `Optional` **sourceMapFilename**: `string`

Source map filename - name under which generated source map (for the main bundle) will be saved.

#### Defined in

[packages/repack/src/types.ts:156](https://github.com/callstack/repack/blob/9e6a11a/packages/repack/src/types.ts#L156)
